@@ -470,23 +470,20 @@ cheese_camera_set_video_recording (CheeseCamera *camera, GError **error)
   GstElement          *video_enc;
   GstElement          *mux;
 
-  if ((video_enc = gst_element_factory_make ("theoraenc", "theoraenc")) == NULL)
+  if ((video_enc = gst_element_factory_make ("vp8enc", "vp8enc")) == NULL)
   {
-    cheese_camera_set_error_element_not_found (error, "theoraenc");
+    cheese_camera_set_error_element_not_found (error, "vp8enc");
     return;
   }
   g_object_set (priv->camerabin, "video-encoder", video_enc, NULL);
-  g_object_set (G_OBJECT (video_enc), "speed-level", 2, NULL);
+  g_object_set (G_OBJECT (video_enc), "speed", 2, NULL);
 
-  if ((mux = gst_element_factory_make ("oggmux", "oggmux")) == NULL)
+  if ((mux = gst_element_factory_make ("webmmux", "webmmux")) == NULL)
   {
-    cheese_camera_set_error_element_not_found (error, "oggmux");
+    cheese_camera_set_error_element_not_found (error, "webmmux");
     return;
   }
   g_object_set (priv->camerabin, "video-muxer", mux, NULL);
-  g_object_set (G_OBJECT (mux),
-                "max-delay", (guint64) 10000000,
-                "max-page-delay", (guint64) 10000000, NULL);
 }
 
 /*
