@@ -35,7 +35,7 @@
 #define EOG_THUMB_NAV_GET_PRIVATE(object) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((object), EOG_TYPE_THUMB_NAV, EogThumbNavPrivate))
 
-G_DEFINE_TYPE (EogThumbNav, eog_thumb_nav, GTK_TYPE_HBOX);
+G_DEFINE_TYPE (EogThumbNav, eog_thumb_nav, GTK_TYPE_BOX);
 
 #define EOG_THUMB_NAV_SCROLL_INC     20
 #define EOG_THUMB_NAV_SCROLL_MOVE    20
@@ -356,13 +356,11 @@ eog_thumb_nav_constructor (GType                  type,
                            GObjectConstructParam *construct_params)
 {
   GObject            *object;
-  EogThumbNav        *nav;
   EogThumbNavPrivate *priv;
 
   object = G_OBJECT_CLASS (eog_thumb_nav_parent_class)->constructor
              (type, n_construct_properties, construct_params);
 
-  nav  = EOG_THUMB_NAV (object);
   priv = EOG_THUMB_NAV_GET_PRIVATE (object);
 
   if (priv->thumbview != NULL)
@@ -393,7 +391,8 @@ eog_thumb_nav_class_init (EogThumbNavClass *class)
                                                          "Show Buttons",
                                                          "Whether to show navigation buttons or not",
                                                          TRUE,
-                                                         (G_PARAM_READABLE | G_PARAM_WRITABLE)));
+                                                         G_PARAM_READWRITE |
+                                                         G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (g_object_class,
                                    PROP_THUMB_VIEW,
@@ -401,9 +400,9 @@ eog_thumb_nav_class_init (EogThumbNavClass *class)
                                                         "Thumbnail View",
                                                         "The internal thumbnail viewer widget",
                                                         CHEESE_TYPE_THUMB_VIEW,
-                                                        (G_PARAM_CONSTRUCT_ONLY |
-                                                         G_PARAM_READABLE |
-                                                         G_PARAM_WRITABLE)));
+                                                        G_PARAM_CONSTRUCT_ONLY |
+                                                        G_PARAM_READWRITE |
+                                                        G_PARAM_STATIC_STRINGS));
 
   g_type_class_add_private (g_object_class, sizeof (EogThumbNavPrivate));
 }
@@ -435,39 +434,16 @@ eog_thumb_nav_init (EogThumbNav *nav)
                     nav);
 
   g_signal_connect (priv->button_left,
-                    "button-press-event",
+                    "pressed",
                     G_CALLBACK (eog_thumb_nav_start_scroll),
                     nav);
 
   g_signal_connect (priv->button_left,
-                    "button-release-event",
+                    "released",
                     G_CALLBACK (eog_thumb_nav_stop_scroll),
                     nav);
 
-  priv->button_left = gtk_button_new ();
-  gtk_button_set_relief (GTK_BUTTON (priv->button_left), GTK_RELIEF_NONE);
-
-  arrow = gtk_arrow_new (GTK_ARROW_LEFT, GTK_SHADOW_ETCHED_IN);
-  gtk_container_add (GTK_CONTAINER (priv->button_left), arrow);
-
-  gtk_widget_set_size_request (GTK_WIDGET (priv->button_left), 25, 0);
-
-  g_signal_connect (priv->button_left,
-                    "clicked",
-                    G_CALLBACK (eog_thumb_nav_button_clicked),
-                    nav);
-
-  g_signal_connect (priv->button_left,
-                    "button-press-event",
-                    G_CALLBACK (eog_thumb_nav_start_scroll),
-                    nav);
-
-  g_signal_connect (priv->button_left,
-                    "button-release-event",
-                    G_CALLBACK (eog_thumb_nav_stop_scroll),
-                    nav);
-
-  priv->vbox = gtk_vbox_new (FALSE, 0);
+  priv->vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   priv->sw = gtk_scrolled_window_new (NULL, NULL);
 
@@ -524,12 +500,12 @@ eog_thumb_nav_init (EogThumbNav *nav)
                     nav);
 
   g_signal_connect (priv->button_right,
-                    "button-press-event",
+                    "pressed",
                     G_CALLBACK (eog_thumb_nav_start_scroll),
                     nav);
 
   g_signal_connect (priv->button_right,
-                    "button-release-event",
+                    "released",
                     G_CALLBACK (eog_thumb_nav_stop_scroll),
                     nav);
 
@@ -547,12 +523,12 @@ eog_thumb_nav_init (EogThumbNav *nav)
                     nav);
 
   g_signal_connect (priv->button_down,
-                    "button-press-event",
+                    "pressed",
                     G_CALLBACK (eog_thumb_nav_start_scroll),
                     nav);
 
   g_signal_connect (priv->button_down,
-                    "button-release-event",
+                    "released",
                     G_CALLBACK (eog_thumb_nav_stop_scroll),
                     nav);
 
@@ -570,12 +546,12 @@ eog_thumb_nav_init (EogThumbNav *nav)
                     nav);
 
   g_signal_connect (priv->button_up,
-                    "button-press-event",
+                    "pressed",
                     G_CALLBACK (eog_thumb_nav_start_scroll),
                     nav);
 
   g_signal_connect (priv->button_up,
-                    "button-release-event",
+                    "released",
                     G_CALLBACK (eog_thumb_nav_stop_scroll),
                     nav);
 
@@ -605,7 +581,6 @@ eog_thumb_nav_new (GtkWidget *thumbview,
                    gboolean   show_buttons)
 {
   EogThumbNav        *nav;
-  EogThumbNavPrivate *priv;
 
   nav = g_object_new (EOG_TYPE_THUMB_NAV,
                       "show-buttons", show_buttons,
@@ -614,8 +589,6 @@ eog_thumb_nav_new (GtkWidget *thumbview,
                       "spacing", 0,
                       NULL);
 
-  priv = nav->priv;
-
   return GTK_WIDGET (nav);
 }
 
